/*******************************************************************
*
*  DESCRIPTION: Atomic Model DataTransmitter
*
*  AUTHOR: Mohammad Moallemi
*
*  EMAIL: mmoallem@connect.carleton.ca
*
*
*  DATE: 1/11/2007
*
*******************************************************************/

/** include files **/
#include <math.h>            // fabs( ... )
#include <stdlib.h>
#include "DataTransmitter.h"  // base header
#include "message.h"       // InternalMessage ....
#include "mainsimu.h"      // class MainSimulator
#include "strutil.h"       // str2float( ... )

/*******************************************************************
* Function Name: DataTransmitter
* Description: constructor
********************************************************************/
DataTransmitter::DataTransmitter( const string &name )
: Atomic( name )
, in3( addInputPort( "in3" ) )
, in4( addInputPort( "in4" ) )
, out3( addOutputPort( "out3" ) )
, out4( addOutputPort( "out4" ) )
, processingtime (0,0,2,0)
{
	
	string time1( MainSimulator::Instance().getParameter( description(), "processingtime" ) ) ;

	if( time1 != "" )
		processingtime = time1 ;

}

/*******************************************************************
* Function Name: externalFunction
* Description: the DataTransmitter receives in3, in4
********************************************************************/
Model &DataTransmitter::externalFunction( const ExternalMessage &msg )
{
  if ( this->state() == passive)
  {
  
    if (msg.port() == in3)
     {
        got_data1 = 1;  //set it to True
        got_data2 = 0;  //set it to False	
        holdIn(active, processingtime);
     }
    if (msg.port() == in4 )
     {
        got_data1 = 0;  //set it to False
        got_data2 = 1;  //set it to True	
       holdIn(active, processingtime);
     }
     
	
  }
	return *this ;
}

/*******************************************************************
* Function Name: internalFunction
********************************************************************/
Model &DataTransmitter::internalFunction( const InternalMessage & )
{
	passivate();
	return *this;
}

/*******************************************************************
* Function Name: outputFunction
********************************************************************/
Model &DataTransmitter::outputFunction( const InternalMessage &msg )
{

      if ( got_data1 == 1 )
        {
         sendOutput( msg.time(), out4, 1);
        }
         
      if (got_data2 == 1)
        {
         sendOutput( msg.time(), out3, 1);
        }
      
	return *this;
}


