/*******************************************************************
*
*  DESCRIPTION: Atomic Model UserLaptop
*
*  AUTHOR: Mohammad Moallemi
*
*  EMAIL: mmoallem@connect.carleton.ca
*
*
*  DATE: 1/11/2007
*
*******************************************************************/

/** include files **/
#include <math.h>            // fabs( ... )
#include <stdlib.h>
#include "UserLaptop.h"  // base header
#include "message.h"       // InternalMessage ....
#include "mainsimu.h"      // class MainSimulator
#include "strutil.h"       // str2float( ... )

/*******************************************************************
* Function Name: UserLaptop
* Description: constructor
********************************************************************/
UserLaptop::UserLaptop( const string &name )
: Atomic( name )
, connect( addInputPort( "connect" ) )
, availability( addInputPort( "availability" ) )
, connection( addInputPort( "connection" ) )
, data_in( addInputPort( "data_in" ) )
, search_network( addOutputPort( "search_network" ) )
, send_PIN( addOutputPort( "send_PIN" ) )
, data_out( addOutputPort( "data_out" ) )
, internet_data( addOutputPort( "internet_data" ) )
, searchnettime (0,0,2,0)
, PINverificationtime (0,0,5,0) 
, transmissiontime (0,0,2,0)
{
	string time1( MainSimulator::Instance().getParameter( description(), "searchnettime" ) ) ;

	if( time1 != "" )
		searchnettime = time1 ;
	
	string time2( MainSimulator::Instance().getParameter( description(), "PINverificationtime" ) ) ;

	if( time2 != "" )
		PINverificationtime = time2 ; 
		
	string time3( MainSimulator::Instance().getParameter( description(), "transmissiontime" ) ) ;

	if( time3 != "" )
		transmissiontime = time3 ;

}

/*******************************************************************
* Function Name: externalFunction
* Description: the UserLaptop receives user_connect, net_available, net_connected or data
********************************************************************/
Model &UserLaptop::externalFunction( const ExternalMessage &msg )
{
  if ( this->state() == passive)
  {
  
    if (msg.port() == connect)
     {
		user_connect=1;		//set it to True
		net_available=0; 	//set it to False
		net_connected=0; 	//set it to False
		data=0;				//set it to False
      holdIn(active, searchnettime);
     }
    if (msg.port() == availability )
     {
		user_connect=0;		//set it to False
		net_available=1; 	//set it to True
		net_connected=0; 	//set it to False
		data=0;				//set it to False
        holdIn(active, PINverificationtime);
     }
     if (msg.port() == connection )
     {
		user_connect=0;		//set it to False
		net_available=0; 	//set it to False
		net_connected=1; 	//set it to True
		data=0;				//set it to False
      
       holdIn(active, transmissiontime);
       
     }
	if (msg.port() == data_in )
     {
		user_connect=0;		//set it to False
		net_available=0; 	//set it to False
		net_connected=0; 	//set it to False
		data=1;				//set it to True
       holdIn(active, transmissiontime);
      }
	
  }
	return *this ;
}

/*******************************************************************
* Function Name: internalFunction
********************************************************************/
Model &UserLaptop::internalFunction( const InternalMessage & )
{
	passivate();
	return *this;
}

/*******************************************************************
* Function Name: outputFunction
********************************************************************/
Model &UserLaptop::outputFunction( const InternalMessage &msg )
{

      if ( user_connect == 1 )
        {
         sendOutput( msg.time(),search_network, 1);
        }
         
        if ( net_available == 1 )
        {
         sendOutput( msg.time(),send_PIN,PIN);
        }
      if (net_connected == 1)
        {
         sendOutput (msg.time(),data_out,1);
        }
      if (data == 1)
        {
         sendOutput (msg.time(),internet_data,1);
        }
	return *this;
}


